@@ -114,7 +114,17 @@ class PresenceService(ExportedGObject):
         self._connected_plugins = set()
 
         for tp in self._plugins:
-            self._setup_tp(tp)
+            self._handles_buddies[tp] = {}
+            self._activities_by_handle[tp] = {}
+
+            tp.connect('status', self._tp_status_cb)
+            tp.connect('contacts-online', self._contacts_online)
+            tp.connect('contacts-offline', self._contacts_offline)
+            tp.connect('activity-invitation',
+                                        self._activity_invitation)
+            tp.connect('private-invitation',
+                                        self._private_invitation)
+            tp.connect('want-to-connect', self._want_to_connect)
             tp.start()
 
         self._contacts_online_queue = []
@@ -127,19 +137,6 @@ class PresenceService(ExportedGObject):
         self._bus_name = dbus.service.BusName(_PRESENCE_SERVICE,
                                               bus=self._session_bus)
 
-    def _setup_tp(self, tp):
-        self._handles_buddies[tp] = {}
-        self._activities_by_handle[tp] = {}
-
-        tp.connect('status', self._tp_status_cb)
-        tp.connect('contacts-online', self._contacts_online)
-        tp.connect('contacts-offline', self._contacts_offline)
-        tp.connect('activity-invitation',
-                   self._activity_invitation)
-        tp.connect('private-invitation',
-                   self._private_invitation)
-        tp.connect('want-to-connect', self._want_to_connect)
-
     @property
     def owner(self):
         return self._owner
@@ -861,20 +858,16 @@ class PresenceService(ExportedGObject):
             self._server_plugin.sync_friends(keys)
 
     @dbus.service.method(PRESENCE_INTERFACE, in_signature="",
-                         out_signature="")
-    def RetryConnections(self):
-        """Reload configuration and retry connections on all managers."""
-        if self._server_plugin is None:
-            server = self._owner.get_server()
-            if server and len(server):
-                tp = ServerPlugin(self._registry, self._owner)
-                self._setup_tp(tp)
-                self._server_plugin = tp
-                self._plugins.append(self._server_plugin)
-
-        for tp in self._plugins:
-            tp.reload_account_info()
-            tp.start()
+            out_signature="")
+    def RestartServerConnection(self):
+        """Stop and restart the server_plugin.
+        
+        This allows changing jabber servers without restarting Sugar.
+        """
+        if self._server_plugin:
+            if self._server_plugin.status == CONNECTION_STATUS_CONNECTED:
+                self._server_plugin.cleanup()
+                self._server_plugin.start()
 
 def main(test_num=0, randomize=False):
     loop = gobject.MainLoop()
